# pylomena

[![Tests](https://github.com/flynnmlp/pylomena/actions/workflows/tests.yml/badge.svg)](https://github.com/flynnmlp/pylomena/actions/workflows/tests.yml)
[![GitHub license](https://img.shields.io/github/license/flynnmlp/pylomena)](https://github.com/flynnmlp/pylomena/blob/main/LICENSE)
[![PyPI package version](https://img.shields.io/pypi/v/pylomena)](https://pypi.org/project/pylomena/)
[![Python versions](https://img.shields.io/pypi/pyversions/pylomena)](https://www.python.org)

Python client for accessing Philomena based imageboards

